# sssekai
Command-line tool (w/Python API support) for downloading/deobfuscating the game's assets, along with some other tools.

# Installation
**For Windows Users** : Builds are available [here](https://github.com/mos9527/sssekai/releases)

Or get the latest version from PyPi:
```bash
    pip install sssekai
```

# Documentation
See the [wiki page!](https://github.com/mos9527/sssekai/wiki)

# See Also
https://github.com/mos9527/sssekai_blender_io